/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.command;

import net.sourceforge.plantuml.AbstractPSystem;
import net.sourceforge.plantuml.regex.IRegex;
import net.sourceforge.plantuml.regex.RegexConcat;
import net.sourceforge.plantuml.regex.RegexLeaf;
import net.sourceforge.plantuml.regex.RegexResult;
import net.sourceforge.plantuml.utils.LineLocation;

public class CommandPage extends SingleLineCommand2<AbstractPSystem> {

	public static final CommandPage ME = new CommandPage();

	private CommandPage() {
		super(getRegexConcat());
	}

	static IRegex getRegexConcat() {
		return RegexConcat.build(CommandPage.class.getName(), RegexLeaf.start(), //
				new RegexLeaf("page"), //
				RegexLeaf.spaceOneOrMore(), //
				new RegexLeaf("NB1", "(\\d+)"), //
				RegexLeaf.spaceZeroOrMore(), //
				new RegexLeaf("x*"), //
				RegexLeaf.spaceZeroOrMore(), //
				new RegexLeaf("NB2", "(\\d+)"), RegexLeaf.end()); //
	}

	@Override
	protected CommandExecutionResult executeArg(AbstractPSystem system, LineLocation location, RegexResult arg, ParserPass currentPass) {

		final int horizontal = Integer.parseInt(arg.get("NB1", 0));
		final int vertical = Integer.parseInt(arg.get("NB2", 0));
		if (horizontal <= 0 || vertical <= 0)
			return CommandExecutionResult.error("Argument must be positive");

		system.setSplitPagesHorizontal(horizontal);
		system.setSplitPagesVertical(vertical);
		return CommandExecutionResult.ok();
	}

}
